#!/bin/bash


#  slackbuild script for mrxvt
# Author: Mark Tucker
# Created: Sep 19, 2004
# Changes:
#        Sep 19, 2004 - initial creation
#        Nov 30, 2004 - updated for 0.3.9
#        Jan 03, 2005 - updated for 0.3.11
#        Aug 27, 2005 - Updated for 0.4.1 and slackbuild functions

#
#----------------------------------------------------------------------

umask 0022

#----------------------------------------
# include the common functions
#----------------------------------------
if [ -r ./sbuild.functions ]; then
    . ./sbuild.functions
else
    echo Cannot read file `pwd`/sbuild.functions
    echo Exiting....
    echo
    exit
fi

#----------------------------------------
# Set locations for temp directories
#----------------------------------------
# location of source code archive
srcdir=`pwd`/SRC
workdir=`pwd`


#----------------------------------------
# Package variables
#----------------------------------------
source="mrxvt-0.4.1.tar.gz"
pkgname="mrxvt"
pkgver="0.4.1"
release="1mht"
package="$pkgname-$pkgver-i486-$release.tgz"
realname="Mark Tucker"
echo Package: $package

#----------------------------------------
# setup path variables
#----------------------------------------
set_workdir

# unpack the source
echo Unpacking the source...
tar -xzf $srcdir/$source


cd $builddir

#----------------------------------------
# setup the build environment
#----------------------------------------
export CFLAGS="-O2 -march=i486 -mcpu=i686"
export CPPFLAGS="-O2 -march=i486 -mcpu=i686"
export CXXFLAGS=$CPPFLAGS


#----------------------------------------
# Build the package and install
#----------------------------------------
# configure 
conf_opts=" --prefix=/usr \
    --sysconfdir=/etc \
    --localstatedir=/var \
    --enable-mousewheel \
    --enable-menubar"
run_configure $conf_opts

# make
run_make

# Set target directory
set_target

# install
run_makeinstall


echo finishing install...


# create install dir
mkdir $target/install

#----------------------------------------
# create slack-desc file to install
#----------------------------------------
cat > $target/install/slack-desc << END
             |-----handy-ruler------------------------------------------------------|
$pkgname: $pkgname $pkgver multi-tabbed terminal emulator
$pkgname: Mrxvt (previously named as materm) is a lightweight and
$pkgname: powerful multi-tabbed X terminal emulator based on the popular
$pkgname: rxvt and aterm. It implements many useful features seen in some
$pkgname: modern X terminal emulators, like gnome-terminal and konsole,
$pkgname: but keep to be lightweight and independent from the GNOME and
$pkgname: KDE desktop environment
$pkgname:
$pkgname: http://materm.sourceforge.net
$pkgname:
$pkgname: Packaged by $realname for $slackver 
END


# create documentation directory
create_docdir

# fix group on bin directories.
fix_bingrp

# strip  bin files
strip_bin

# strip lib files
strip_libs

# check for uncompressed man pages
compr_man

# makepkg
create_pkg

exit

